#
# spec file for package openstack-neutron-lbaas
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component neutron-lbaas
%define groupname %{component}
%define username %{component}

%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif

%define version_unconverted 13.0.1.dev5

Name:           openstack-neutron-lbaas
Version:        13.0.1~dev5
Release:        264.1
Summary:        Neutron Load Balancer As A Service
License:        Apache-2.0
Group:          System/Management
Url:            https://launchpad.net/neutron
Source:         http://tarballs.openstack.org/neutron-lbaas/neutron-lbaas-stable-rocky.tar.gz
Source1:        %{name}.logrotate
Source2:        %name.conf
Source3:        rpmlintrc
# systemd service files
Source10:       %{name}v2-agent.service
BuildRequires:  crudini
BuildRequires:  fdupes
BuildRequires:  openstack-neutron
BuildRequires:  openstack-suse-macros
BuildRequires:  openstack-suse-sudo
BuildRequires:  python-barbicanclient
BuildRequires:  python-cryptography
BuildRequires:  python-devel
BuildRequires:  python-keystoneauth1
BuildRequires:  python-neutron-lib
BuildRequires:  python-pbr
# Test requirements
BuildRequires:  python-WebTest
BuildRequires:  python-fixtures
BuildRequires:  python-mock
BuildRequires:  python-oslo.config
BuildRequires:  python-oslo.reports
BuildRequires:  python-oslotest
BuildRequires:  python-python-subunit
BuildRequires:  python-requests-mock
BuildRequires:  python-testrepository
BuildRequires:  python-testresources
BuildRequires:  python-testscenarios
BuildRequires:  python-testtools
# Documentation build requirements:
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       logrotate
Requires:       openstack-suse-sudo
Requires:       python >= 2.7
Requires:       python-%{component} = %{version}
Requires(pre):  pwdutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
PreReq:         %fillup_prereq

%description
Neutron is a virtual network service for Openstack.

Just like OpenStack Nova provides an API to dynamically request and
configure virtual servers, Neutron provides an API to dynamically
request and configure virtual networks. These networks connect
"interfaces" from other OpenStack services (e.g., vNICs from Nova VMs).
The Neutron API supports extensions to provide advanced network
capabilities (e.g., QoS, ACLs, network monitoring, etc)

%package -n python-neutron-lbaas
Summary:        Neutron Load Balancer As A Service - Python module
Group:          Development/Languages/Python
Requires:       python >= 2.7
Requires:       python-SQLAlchemy >= 1.0.10
Requires:       python-WebOb >= 1.7.1
Requires:       python-alembic >= 0.8.10
Requires:       python-barbicanclient >= 4.5.2
Requires:       python-cryptography >= 2.1
Requires:       python-eventlet >= 0.18.2
Requires:       python-keystoneauth1 >= 3.4.0
Requires:       python-netaddr >= 0.7.18
Requires:       python-neutron-lib >= 1.18.0
Requires:       python-oslo.concurrency >= 3.26.0
Requires:       python-oslo.config >= 5.2.0
Requires:       python-oslo.db >= 4.27.0
Requires:       python-oslo.log >= 3.36.0
Requires:       python-oslo.messaging >= 5.29.0
Requires:       python-oslo.reports >= 1.18.0
Requires:       python-oslo.serialization >= 2.18.0
Requires:       python2-oslo.service
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-pbr >= 2.0.0
Requires:       python-pyOpenSSL >= 17.1.0
Requires:       python-pyasn1 >= 0.1.8
Requires:       python-pyasn1-modules >= 0.0.6
Requires:       python-requests >= 2.14.2
Requires:       python-six >= 1.10.0
Requires:       python-stevedore >= 1.20.0

%description -n python-neutron-lbaas
This package contains the core Python module of OpenStack Neutron LBaaS


%package agent
Summary:        Neutron Load Balancer As A Service - Load Balancing Agent
Group:          Development/Languages/Python
PreReq:         %name = %version
Requires:       haproxy

%description agent
This package provides the Load Balancing as a Service Agent.

%prep
%setup -q -n neutron-lbaas-%{version_unconverted}
%openstack_cleanup_prep

%build
python setup.py build
python setup.py build_sphinx -b man

### configuration files
for x in `ls etc/oslo-config-generator/*`; do
    PYTHONPATH=. oslo-config-generator --config-file $x
done

%install
python setup.py install --skip-build --prefix=%{_prefix} --root=%{buildroot} --install-data=/

### directories
install -d -m 750 %{buildroot}%{_localstatedir}/lib/%{component}
install -d -m 750 %{buildroot}%{_localstatedir}/cache/%{component}
install -d -m 700 %{buildroot}%{_rundir}/%{component}
install -D -m 644 %{SOURCE2} %{buildroot}/%_tmpfilesdir/%name.conf

### configuration files
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/neutron-lbaasv2-agent.conf.d/

# all needed files are installed automatically
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

install -p -D -m 644 etc/neutron_lbaas.conf.sample %{buildroot}%{_sysconfdir}/neutron/neutron_lbaas.conf
install -p -D -m 644 etc/lbaas_agent.ini.sample %{buildroot}%{_sysconfdir}/neutron/lbaas_agent.ini
install -p -D -m 644 etc/services_lbaas.conf.sample %{buildroot}%{_sysconfdir}/neutron/services_lbaas.conf

# Install systemd unit services
mkdir -p %{buildroot}%{_sbindir} %{buildroot}%{_unitdir}
install -p -D -m 444 %{SOURCE10} %{buildroot}%{_unitdir}/%{name}v2-agent.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}v2-agent

### documentation
install -d %{buildroot}%{_mandir}/man1
install -m 644 doc/build/man/*.1 %{buildroot}%{_mandir}/man1

## SUSE configuration defaults
crudini --set %{buildroot}/etc/neutron/lbaas_agent.ini DEFAULT interface_driver neutron.agent.linux.interface.BridgeInterfaceDriver
crudini --set %{buildroot}/etc/neutron/neutron_lbaas.conf service_providers service_provider "LOADBALANCERV2:Haproxy:neutron_lbaas.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default"

### misc
%fdupes %{buildroot}%{python_sitelib}/%{component}
%fdupes %{buildroot}%{_bindir}

### authentication cache dir
mkdir -p %{buildroot}%{_localstatedir}/cache/%{component}

## %check
## python setup.py testr

%pre
%openstack_pre_user_group_create %{username} %{groupname}

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%pre agent
%service_add_pre openstack-neutron-lbaasv2-agent

%post agent
%service_add_post openstack-neutron-lbaasv2-agent

%preun
%service_del_preun openstack-neutron-lbaasv2-agent

%postun
%restart_on_update openstack-neutron-lbaasv2-agent
%service_del_postun openstack-neutron-lbaasv2-agent

%files
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE 
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/lib/%{component}
%_tmpfilesdir/%name.conf
%dir %{_sysconfdir}/neutron/neutron-lbaasv2-agent.conf.d/
%config(noreplace) %{_sysconfdir}/neutron/neutron_lbaas.conf
%config(noreplace) %{_sysconfdir}/neutron/services_lbaas.conf
%{_mandir}/man1/neutron-lbaas.1%{?ext_man}

%files agent
%defattr(-,root,root,-)
%license LICENSE
%{_bindir}/neutron-lbaasv2-agent
%config(noreplace) %{_sysconfdir}/neutron/lbaas_agent.ini
%config %{_sysconfdir}/neutron/rootwrap.d/lbaas-haproxy.filters
%{_unitdir}/openstack-neutron-lbaasv2-agent.service
%{_sbindir}/rcopenstack-neutron-lbaasv2-agent

%files -n python-neutron-lbaas
%defattr(-,root,root,-)
%license LICENSE
%{python_sitelib}/neutron_lbaas/
%{python_sitelib}/neutron_lbaas-*.egg-info

%changelog
* Fri Oct 19 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.1.dev5:
  * Updated "create\_pool" method in plugin
  * Update L7-proxy gate to allow new Octavia features
* Tue Sep  4 2018 opensuse-packaging@opensuse.org
- Update to version neutron-lbaas-13.0.1.dev3:
  * import zuul job settings from project-config
  13.0.0
* Fri Aug 31 2018 kwu@suse.com
- switch to stable/rocky branch
* Wed Aug 29 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0rc2.dev15:
  * Gate API test for the lbaasv2-proxy plugin
* Sat Aug 25 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0rc2.dev13:
  * switch documentation job to new PTI
  * import zuul job settings from project-config
  * use setup\_extension in unit tests
  * Do not run dsvm tests if locales change
* Mon Aug 20 2018 nicolas.bock@suse.com
- Fix linter warnings about licenses
* Mon Aug 20 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0rc2.dev5:
  * Disable KVM at OVH
  * Imported Translations from Zanata
* Mon Aug 13 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0rc2.dev3:
  * Fix proxy extension for neutron RBAC
* Fri Aug 10 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0rc2.dev1:
  * Update reno for stable/rocky
  13.0.0.0rc1
* Wed Aug  8 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b4.dev3:
  * Fix neutron-lbaas tempest for filter validation
* Fri Aug  3 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b4.dev2:
  * update requirements for neutron-lib 1.18.0
  13.0.0.0b3
  * Neutron-LBaaS to Octavia migration tool
  * Add release notes link in README
  * Update new documentation PTI jobs
* Sat Jul 14 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b3.dev12:
  * Fix cookie session persistence in namespace driver
* Wed Jul 11 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b3.dev10:
  * Re-enable KVM
  * Fix the None value of Q\_PLUGIN\_CONF\_FILE if enable neutron-\*
  * Improve speed of listing from DB
  * Add gate for Direct L7-Proxy to Octavia
  * Exclude limestone from running with kvm
  * Allow to create loadbalancer with chinese character
  * fix tox python3 overrides
  13.0.0.0b2
  * use retry\_db\_errors from neutron-lib
  * Get providers directly from ORM to make startup take half as long
  * Fix EntityInUse exception message
  * remove unused plugin.get\_plugin\_name()
  * Fix AtrributeError in update\_listener
  * Remove key "l7\_policies" in pool dict
  * tempest: healthmonitor is deleted via resource\_cleanup
* Wed May  2 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b2.dev6:
  * Log failed cert delete, and raise TLSContainerInvalid instead
* Fri Apr 27 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b2.dev5:
  * use rpc Connection rather than create\_connection
* Wed Apr 25 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b2.dev3:
  * Modify a detail in parse\_stat
* Tue Apr 24 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b2.dev2:
  * Accommodate for neutron code that expires obsolete relationships
* Fri Apr 20 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-13.0.0.0b2.dev1:
  * uncap eventlet
  13.0.0.0b1
* Sat Apr 14 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev21:
  * Fix the double zuul project definition
  * Cap haproxy log level severity
* Fri Apr 13 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev18:
  * Fix pep8 errors
* Sun Apr  1 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev17:
  * Choose correct log option by listener protocol
* Fri Mar 30 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev15:
  * add lower-constraints job
* Thu Mar 29 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev13:
  * Updated from global requirements
* Wed Mar 21 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev12:
  * Add a compatible check before creating pool
* Sun Mar 18 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev11:
  * Updated from global requirements
* Thu Mar 15 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev10:
  * Remove tox\_install.sh
  * Imported Translations from Zanata
* Wed Mar 14 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev7:
  * Updated from global requirements
  * Reduce stestr concurrency to 1 for tempest jobs
* Fri Mar  9 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.1.dev4:
  * Switch to stestr and wait for LB delete on cleanup
  12.0.0
* Mon Feb 26 2018 cloud-devel@suse.de
- Update to version neutron-lbaas-12.0.0.0rc2.dev3:
  * Updated from global requirements
  * Don't run scenario jobs for docs changes
* Tue Feb 13 2018 tbechtold@suse.com
- Update to version neutron-lbaas-12.0.0.0rc2.dev1:
  * Update reno for stable/queens
  12.0.0.0rc1
  * Fix "unable to delete subnet" in API tests
  * Zuul: Remove project name
  * Update releasenotes config for storyboard bugs
  * Mark neutron-lbaas as deprecated
  * Updated from global requirements
  12.0.0.0b3
  * Adds the missing stats command and fixes status
  * Cleanup test-requirements
  * Updated from global requirements
  * Imported Translations from Zanata
  * use api attributes from neutron-lib
  * Remove unnecessary lazy-loaded queries
  * use callbacks from neutron-lib
  * Use generic netcat syntax in base scenario
  * Updated from global requirements
  * Fix the deprecated usage of "get\_transport"
  * Updated from global requirements
  12.0.0.0b2
  * Octavia Proxy Plugin
  * Update pool member operating status for haproxy
  * Imported Translations from Zanata
  * Fix deprecated translation
  * Remove setting of version/release from releasenotes
  * Updated from global requirements
  * use agent api def from neutron-lib
  * use flavors api def from neutron-lib
  * Fix to prevent password from being displayed in logs
  * Add missing NAME attribute for SessionPersistenceV2
  * Updated from global requirements
  * Update the doc link
  * Fix tempest scenario tests waiters
  * More zuul v3 job cleanup after newton EOL
  * Updated from global requirements
  * Fix a tempest deprecation warning
  * Update release notes doc theme
  * Fix a unit test for cryptography 2.1
  * Disable kvm on OVH infra instances
  * Fix usage of the method ensure\_dir
  * Zuul: add file extension to playbook path
  * Octavia driver to honor Octavia API status codes
  * Remove common jobs from zuul.d
  * use FAULT\_MAP from neutron-lib
  * Move neutron-lbaas zuulv3 configuration in repo
  12.0.0.0b1
  * Add setup\_privsep in agent's main function
  * Remove SCREEN\_LOGDIR from devstack
  * Updated from global requirements
  * Switch devstack plugin to keystone v3
  * Shrink Tempest scenario manager copy
  * Updated from global requirements
  * Fix logging for lb timeout operations
  * Don't forget to call the super's resource\_cleanup
  * Updating import for linux/interface opts
  * Updated from global requirements
  * Stop registering "graphs" resource to quota
  * Replace deprecated tempest test.is\_extension\_enabled()
  * Use flake8-import-order plugin
  * Remove vestigate HUDSON\_PUBLISH\_DOCS reference
  * Updated from global requirements
  * Update links in README
  * fixed statuses, as it was using an undefined variable
  * Updated from global requirements
  * Updated from global requirements
  * Update reno for stable/pike
  * make lbaasv2 support "https" keystone endpoint
  11.0.0
  * Updated from global requirements
  * Fix a bad barbicanclient test
  * Add "delay" value determination for health monitor
  * Updated from global requirements
  11.0.0.0b3
  * Updated from global requirements
  * Updated from global requirements
  * use synchronized decorator from neutron-lib
  * consume load\_class\_by\_alias\_or\_classname from neutron-lib
  * Replace deprecated test.attr with decorators.attr
  * Remove some LBaaSv1 references
  * Adds L7 policy and rule support
  * Updated from global requirements
  * Enhancements for the the back-end system
  * fixed health monitor setting during tempest test,
  * removing WebTest from test-deps
  * Fix a namespace collision issue
  * use service type constants from neutron\_lib plugins
  * Updated from global requirements
  * Send haproxy stat command as bytes
  * Replace the usage of 'manager' with 'os\_primary'
  * Raise VipNetworkInvalid when create lb with no-subnets vipnet
  * Remove support for py34
  * Updated from global requirements
  * devstack: Adapt to lib/neutron
  * Fixes module not found error in NetScaler LBaaSV2 driver
  * Updated from global requirements
  * Remove usage of parameter enforce\_type
  * Updated from global requirements
  * Replace assertEqual([], items) with assertEmpty(items)
  11.0.0.0b2
  * Updated from global requirements
  * Updated from global requirements
  * Adding configuration flag for skipping SSL certificate verification
  * Fix the wrong device\_owner when recreate LBaas listener
  * tempest: Add a config for session persistence types
  * Rename driver to support different versions
  * Updated from global requirements
  * Updated from global requirements
  * Remove get\_namespace from API extensions
  * Remove log translations from neutron-lbaas
  * Use Tempest TimeoutException from tempest.lib
  * Fix faulty unit test in haproxy driver
  * scenario test: configure scenario test protocols
  * Trying a different strategy for fixing py3 errors in testing
  * Use OS\_AUTH\_URL instead of baked in defaults
  * Fix doc generation for Python3
  * Migrate Constants from neutron.plugin to neutron\_lib
  * Fix py3x errors in tempest testing
  * Updated from global requirements
  11.0.0.0b1
  * Optimize the link address
  * Fix exception about loadbalancer\_stats
  * Create header with authtoken for requests without args
  * Remove subunit-trace fork
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Tests helper function \_send\_requests should catch socket.error
  * Explicitly list neutron api extensions for tests
  * Updated from global requirements
  * Fix a releasenotes issue with rst markup
  * Fix README with link to octavia launchpad page
  * Updated from global requirements
  * Use assertIsNone(...) instead of assertEqual(None, ...)
  * Change default auth\_version to v3
  * Updated from global requirements
  * Fix neutron-lbaas gates
  * Switch to use stable data\_utils
  * Switch to use exec\_command instead of mount/umount
  * Fix on \_\_init\_\_ of LoadBalancerManager
  * gate\_hook: Stop writing local.conf directly
  * Use replace\_file from neutron-lib
  * Add decorator for lbaasv2 get\_l7policies
  * Fix the file permissions of test\_db\_loadbalancerv2.py
  * Keep user\_group option of haproxy section in lbaas\_agent.ini
  * Replaces uuid.uuid4 with uuidutils.generate\_uuid()
  * api test: centralize health monitor protocol
  * Set access\_policy for messaging's dispatcher
  * Fix for error "no attribute tenant\_id"
  * api test: Add config options for listener/pool protocol
  * api test: Centralize listener/pool protocol
  * Use DB field sizes instead of \_MAX\_LEN constants
  * Fix typo in v2\_driver.py
  * Temporarily support two INTERFACE\_DRIVER\_OPTS
  * Allow creating loadbalancer with network\_id
  * Expect project\_id in API calls
  * Adds neutron\_lbaas.conf and services\_lbaas.conf to q-svc command line
  * Import model\_base from neutron-lib
  * Add retries upon db error for deleting vip\_port
  * Allow setting "insecure" in neutron\_lbaas.conf
  * Add missing "listener\_id" attribute to L7 policy
  * Fix typo in the rest\_client.py
  * Remove redundant listener existence check in create\_l7policy
  * Remove internal function validate\_integer already implemented in neutron-lib
  * Delete the "self" when call "\_set\_degraded" function
  * Updating imports for services prov\_config options
  * resource\_cleanup method does not delete members
  * gate\_hook: Enable q-lbaas explicitly
  * Use "--pub-key" instead of "--pub\_key"
  * Removing deprecated quota\_items config from tests
  * Set up hooks for the functional job and add test\_migrations test
  * Use tempest.lib tenants\_client
  * Replace old\_lb to old\_pool in function delete\_pool
  * Replace auth\_uri option with auth\_url in DevStack plugin
  * Skip the check \_check\_pool\_loadbalancer\_match in one condition
  * Remove check\_i18n files
  * Remove repeat call to 'neutron\_agent\_lbaas\_install\_agent\_packages'
* Wed Jan 24 2018 dmueller@suse.com
- make user directory not world readable
* Thu Oct 12 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.1.dev27:
  * Updated from global requirements
  * Switch devstack plugin to keystone v3
  * Updated from global requirements
  * Fix logging for lb timeout operations
  * Don't forget to call the super's resource\_cleanup
  * Updating import for linux/interface opts
  * Updated from global requirements
  * Stop registering "graphs" resource to quota
  * Use flake8-import-order plugin
* Sat Sep  9 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.1.dev13:
  * devstack: Adapt to lib/neutron
* Thu Sep  7 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.1.dev12:
  * Update links in README
  * fixed statuses, as it was using an undefined variable
* Wed Sep  6 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.1.dev8:
  * Replace deprecated tempest test.is\_extension\_enabled()
  * Remove vestigate HUDSON\_PUBLISH\_DOCS reference
  * Updated from global requirements
  11.0.0
* Tue Aug 29 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0rc2.dev3:
  * Updated from global requirements
* Sat Aug 19 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0rc2.dev2:
  * Updated from global requirements
* Sun Aug 13 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0rc2.dev1:
  * Update reno for stable/pike
  11.0.0.0rc1
* Wed Aug  9 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b4.dev4:
  * Updated from global requirements
* Tue Aug  8 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b4.dev3:
  * Send haproxy stat command as bytes
* Sat Aug  5 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b4.dev2:
  * Fix a bad barbicanclient test
* Fri Aug  4 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b4.dev1:
  11.0.0.0b3
  * Updated from global requirements
* Fri Jul 28 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev38:
  * Updated from global requirements
  * Updated from global requirements
  * use synchronized decorator from neutron-lib
  * consume load\_class\_by\_alias\_or\_classname from neutron-lib
  * Remove some LBaaSv1 references
* Thu Jul 27 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev29:
  * Replace deprecated test.attr with decorators.attr
  * Adds L7 policy and rule support
  * removing WebTest from test-deps
* Fri Jul 21 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev23:
  * Updated from global requirements
  * fixed health monitor setting during tempest test,
* Thu Jul 20 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev20:
  * Enhancements for the the back-end system
* Wed Jul 19 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev19:
  * Fix a namespace collision issue
* Fri Jul  7 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev18:
  * use service type constants from neutron\_lib plugins
* Thu Jul  6 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev16:
  * Raise VipNetworkInvalid when create lb with no-subnets vipnet
* Thu Jun 29 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev14:
  * Updated from global requirements
* Wed Jun 28 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev13:
  * Replace the usage of 'manager' with 'os\_primary'
* Fri Jun 23 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev11:
  * Remove support for py34
  * Updated from global requirements
  * Fixes module not found error in NetScaler LBaaSV2 driver
* Thu Jun 22 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev6:
  * Updated from global requirements
  * Fix the wrong device\_owner when recreate LBaas listener
* Fri Jun 16 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev4:
  * Remove usage of parameter enforce\_type
  * Replace assertEqual([], items) with assertEmpty(items)
* Wed Jun 14 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b3.dev1:
  11.0.0.0b2
  * Updated from global requirements
* Fri Jun  9 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b2.dev30:
  * tempest: Add a config for session persistence types
* Tue Jun  6 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b2.dev28:
  * Updated from global requirements
  * Adding configuration flag for skipping SSL certificate verification
* Sat Jun  3 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-11.0.0.0b2.dev25:
  * Updated from global requirements
* Mon May 29 2017 tbechtold@suse.com
- Update to version neutron-lbaas-11.0.0.0b2.dev24:
  * Rename driver to support different versions
  * Updated from global requirements
  * Remove get\_namespace from API extensions
  * Remove log translations from neutron-lbaas
  * Use Tempest TimeoutException from tempest.lib
  * Fix faulty unit test in haproxy driver
  * scenario test: configure scenario test protocols
  * Trying a different strategy for fixing py3 errors in testing
  * Use OS\_AUTH\_URL instead of baked in defaults
  * Fix doc generation for Python3
  * Migrate Constants from neutron.plugin to neutron\_lib
  * Fix py3x errors in tempest testing
  * Updated from global requirements
  11.0.0.0b1
  * Optimize the link address
  * Fix exception about loadbalancer\_stats
  * Create header with authtoken for requests without args
  * Remove subunit-trace fork
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Tests helper function \_send\_requests should catch socket.error
  * Explicitly list neutron api extensions for tests
  * Updated from global requirements
  * Fix a releasenotes issue with rst markup
  * Fix README with link to octavia launchpad page
  * Updated from global requirements
  * Use assertIsNone(...) instead of assertEqual(None, ...)
  * Change default auth\_version to v3
  * Updated from global requirements
  * Fix neutron-lbaas gates
  * Updated from global requirements
  * Switch to use stable data\_utils
  * Switch to use exec\_command instead of mount/umount
  * Fix on \_\_init\_\_ of LoadBalancerManager
  * gate\_hook: Stop writing local.conf directly
  * Use replace\_file from neutron-lib
  * Add decorator for lbaasv2 get\_l7policies
  * Fix the file permissions of test\_db\_loadbalancerv2.py
  * Keep user\_group option of haproxy section in lbaas\_agent.ini
  * Replaces uuid.uuid4 with uuidutils.generate\_uuid()
  * api test: centralize health monitor protocol
  * Set access\_policy for messaging's dispatcher
  * Fix for error "no attribute tenant\_id"
  * api test: Add config options for listener/pool protocol
  * api test: Centralize listener/pool protocol
  * Use DB field sizes instead of \_MAX\_LEN constants
  * Fix typo in v2\_driver.py
  * Temporarily support two INTERFACE\_DRIVER\_OPTS
  * Allow creating loadbalancer with network\_id
  * Expect project\_id in API calls
  * Adds neutron\_lbaas.conf and services\_lbaas.conf to q-svc command line
  * Import model\_base from neutron-lib
  * Add retries upon db error for deleting vip\_port
  * Allow setting "insecure" in neutron\_lbaas.conf
  * Add missing "listener\_id" attribute to L7 policy
  * Fix typo in the rest\_client.py
  * Remove redundant listener existence check in create\_l7policy
  * Remove internal function validate\_integer already implemented in neutron-lib
  * Delete the "self" when call "\_set\_degraded" function
  * Updating imports for services prov\_config options
  * resource\_cleanup method does not delete members
  * gate\_hook: Enable q-lbaas explicitly
  * Use "--pub-key" instead of "--pub\_key"
  * Removing deprecated quota\_items config from tests
  * Set up hooks for the functional job and add test\_migrations test
  * Use tempest.lib tenants\_client
  * Replace old\_lb to old\_pool in function delete\_pool
  * Replace auth\_uri option with auth\_url in DevStack plugin
  * Skip the check \_check\_pool\_loadbalancer\_match in one condition
  * Remove check\_i18n files
  * Remove repeat call to 'neutron\_agent\_lbaas\_install\_agent\_packages'
  * Fix no such option defined for service\_auth
  * Neutron-LBaaS: Fix network\_resources path
  * Neutron\_LBaaSv2: Update Session Persistence Bug
  * Port test\_db\_loadbalancer to Python 3
  * Fix test\_quotas
  * Set HTTP status code to 409 for LBs in PENDING\*
  * Port agent\_manager to Python 3
  * Port test\_agent and test\_agent\_api to Python 3
  * Port cert\_parser to Python 3
  * Fix delete of session\_persistence with pool update
  * fix mismatch between v1 keyword and v2 driver in gate\_hook
  * Fix shared-pools lbaas\_listeners migration
  * Set netscaler\_ncc\_password as secret to prevent it from being logged
  * Neutron LBaaS leaking admin\_password into logs
  * Add check for listener's admin\_state\_up status
  * LBaaS: make use of neutron\_lib exceptions
  * Add an explicit BRANCH\_NAME to tox\_install.sh
  * Adding "region and endpoint\_type" parameters to barbican\_acl.py
  * Use the correct \_ method from neutron\_lbaas.\_i18n
  * Replaces \_\_builtin\_\_ with six.moves.builtins
  * Do not send project\_id to Octavia API on PUTs
  * Remove OpenSSL from cert\_parser
  * Change status to DISABLED if admin\_state\_up if false
  * Validate vip\_id as uuid
  * Fix a typo from UPPER\_CONTRAINTS\_FILE to UPPER\_CONSTRAINTS\_FILE
  * [LBaaS v2] Validate name, description and tenant\_id attributes length
  * Send project\_id/tenant\_id to octavia api
  * Switch to internal \_i18n pattern, as per oslo\_i18n guidelines
  * Add service\_plugins entry\_point for LBaaS v2 plugin
  * Revert "Revert "Remove TEMPEST\_CONFIG\_DIR in the api tox env""
  * Revert "Remove TEMPEST\_CONFIG\_DIR in the api tox env"
  * Remove TEMPEST\_CONFIG\_DIR in the api tox env
  * Set ZUUL\_BRANCH using BRANCH if not available
  * Switch to using neutron.common.utils:replace\_file()
  * Fix default device\_driver entry in lbaas\_agent.ini
  * Removed new=True argument from create\_connection
  * [LBaaS v2] Validate http\_method and url\_path for health monitor
  * Filter get\_pool\_members to return members from the desired pool
  * Filter get\_pool\_members to return members from the desired pool
  * Fix typo in test names for test\_health\_monitors\_non\_admin.py in API v2
  * Change ignore-errors to ignore\_errors
  * Add device\_id when a loadbalancer is created instead of at listener create
  * Use "session\_persistence" in data models for uniformity with API attribute
  * Wait for lb delete on tempest resource\_cleanup
  * Add an optional member status of NO\_MONITOR
  * Change sni\_container plural from ids to refs
  * Clean up test\_listener\_basic scenario
  * Remove ipv6\_pd\_enabled from subnet data model
  * Remove load\_admin\_roles from calls to get\_admin\_context
  * Fix typos in namespace\_driver.py and some tests
  * Register alembic\_migrations at install time
  * Stop use of oslo\_utils.timeutils.strtime()
  * Fix for post\_test\_hook.sh
  * Fixes healthmonitor admin\_state\_up not working issue
  * Forcing cert\_parser.dump\_private\_key to use PKCS8
  * ensure\_dir: switch to neutron.common.utils
  * pep8: re-enable neutron-db-manage check\_migration
  * Added admin/non\_admin api tests
  * COMMON\_PREFIXES cleanup - patch 2/5
  * Delete neutron\_lbaas.agent.common\_rpc
  * Neutron\_LBaaS: Update README.rst for Tests
  * Modified tox.ini and post\_test\_hook.sh
  * Switch to oslo\_utils.uuidutils
  * Do not assume http expected\_codes ordering
  * Fix tenant\_id mismatch in test object creation
  * Update subnet data model to include ipv6\_pd\_enabled
  * Switch from neutron.common.log.log to oslo\_log.helpers.log\_method\_call
  * changes to skip negative test cases with invalid/empty tenant\_id
  * Use id attribute of the object in assert\_modifications\_allowed
  * Fixes cert\_parser intermediate validation
  * Included more API tests for neutron\_lbaas
  * Remove test workaround for subnetpool\_id
  * Update subnet data model to include subnetpool\_id
  * Fixed db update\_status to handle healthmonitor
  * Fixes sni\_containers access issues
  * Validate health\_monitor id when associating to pool
  * Error correction of neutron\_lbaas.conf
  * Stop storing and passing root\_helper
  * Exposing the vip\_port\_id attribute of a load balancer
  * Add index on tenant\_id
  * Pass root\_helper to ip\_lib by keyword argument to prep for removal
  * Fix python neutron paths for neutron\_lbaas
  * pretty\_tox.sh: Portablity improvement
  * test\_dhcp\_agent: Fix no-op tests
  * Fix incorrect exception order in \_execute\_request
  * Switch run-time import to using importutils.import\_module
  * Ensure test\_agent\_manager handles random hashseeds
  * mock.assert\_called\_once() is not a valid method
  * Remove faulty .assert\_has\_calls([])
  * Add requests\_mock to test-requirements.txt
  * Supply missing cisco\_cfg\_agent.ini file
  * Remove unused arg to config.setup\_logging()
  * Remove reference to cisco\_cfg\_agent.ini from setup.cfg again
  * Fix state\_path in tests
  * Reorder operations in create\_vip
  * Remove reference to cisco\_cfg\_agent.ini from setup.cfg
  * Use correct section for log message if interface\_driver import fails
  * This patch changes the name of directory from mech\_arista to arista
  * Move plugin.delete\_port call out of transaction
  * Allow to import \_LC, \_LE, \_LI and \_LW functions directly
  * Use auth\_token from keystonemiddleware
  * Change all occurences of no\_delete to do\_delete
  * Remove reference to setuptools\_git
  * Moved rpc\_compat.py code back into rpc.py
  * Removed create\_rpc\_dispatcher methods
  * Renamed consume\_in\_thread -> consume\_in\_threads
  * Added missing core\_plugins symbolic names
  * Introduced rpc\_compat.create\_connection()
  * Sync periodic\_task from oslo-incubator
  * Disallow 'timeout' in health\_monitor to be negative
  * Fix importing module in test\_netscaler\_driver
  * LBaaS: Set correct nullable parameter for agent\_id
  * rename ACTIVE\_PENDING to ACTIVE\_PENDING\_STATUSES
  * Fix usage of save\_and\_reraise\_exception
  * Bugfix and refactoring for ovs\_lib flow methods
  * replace rest of q\_exc to n\_exc in code base
  * Use save\_and\_reraise\_exception when reraise exception
  * add router\_id to response for CRU on fw/vip objs
  * LBaaS: handle NotFound exceptions in update\_status callback
  * Rename check\_nvp\_config utility tool
  * Corrects broken format strings in check\_i18n.py
  * LBaaS: synchronize haproxy deploy/undeploy\_instance methods
  * Add fwaas\_driver.ini to setup.cfg
  * Ensure get\_pid\_to\_kill works with rootwrap script
  * Fix import log\_handler error with publish\_errors set
* Wed Mar 15 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.1.dev46:
  * Updated from global requirements
  * Prevent LBaaSv2 agent from filling up logs
* Fri Mar 10 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.1.dev44:
  * Switch to use stable data_utils
  * Switch to use exec_command instead of mount/umount
  * Use neutron-lib's context module
  * consume ServicePluginBase from neutron-lib
  * [Fix gate]Update test requirement
  * tempest: Switch to local copy of tempset/scenario/manager.py
  * Use tempest.lib's TimeoutException
  * Updated from global requirements
  * Fix KeyError exception in ChanceScheduler.schedule
  * Use replace_file from neutron-lib
  * Add decorator for lbaasv2 get_l7policies
  * Remove unused logging import
  * Trivial-fix:fix typo in .pylintrc
* Wed Mar  1 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.1.dev24:
  * Updated from global requirements
  * Don't use Tempest internal methods
  * Add missing classmethod decorator in l7 extension
* Tue Feb 28 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.1.dev19:
  * Work around devstack selecting incorrect image
  * gate_hook: Stop writing local.conf directly
  10.0.0
* Wed Feb 22 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0rc2.dev17:
  * Fix the file permissions of test_db_loadbalancerv2.py
  * Updated from global requirements
  * Don not create loadbalancer if no eligible lbaasv2 agent
  * scenario test: Open up port for second listener
* Fri Feb 17 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0rc2.dev11:
  * Use the new tempest module
  * Keep user_group option of haproxy section in lbaas_agent.ini
  * Use addCleanup instead of tearDown
  * Adds a sample polic.json file
* Mon Feb 13 2017 tbechtold@suse.com
- Update to version neutron-lbaas-10.0.0.0rc2.dev5:
  * Updated from global requirements
  * Update reno for stable/ocata
  10.0.0.0rc1
  * Only if loadbalancer's status is normal then create pool in db
  10.0.0.0b3
  * Remove psutil dependency
  * Updated from global requirements
  * Use neutron-lib portbindings api-def
  * Don't use the python directly in devstack
  * Updated from global requirements
  * Replaces uuid.uuid4 with uuidutils.generate_uuid()
  * Implements ProcessMonitor in the haproxy driver
  * api test: Check the correct extension
  * VMWare driver support for l7 rules & policies
  * Turn on q-lbaasv2 service by default
  * Replace six.iteritems with dict.items()
  * The lb namespace can not be deleted
* Wed Jan 11 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b3.dev10:
  * Set access_policy for messaging's dispatcher
* Fri Jan  6 2017 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b3.dev8:
  * Fix for error "no attribute tenant_id"
  * Updated from global requirements
  * Fix a typo
* Thu Dec 29 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b3.dev4:
  * Updated from global requirements
* Wed Dec 21 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b3.dev3:
  * Updated from global requirements
  10.0.0.0b2
* Sat Dec 17 2016 tbechtold@suse.com
- Add conf.d/ dir
* Thu Dec 15 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev20:
  * Auto reschedule loadbalancers from dead agents
* Tue Dec 13 2016 tbechtold@suse.com
- Fix typo in service file
* Mon Dec 12 2016 vuntz@suse.com
- Remove Wants from systemd service file, to avoid issues when
  using HA.
* Mon Dec 12 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev18:
  * Updated from global requirements
* Sat Dec 10 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev16:
  * Add support to update members in LBaaS extension
* Wed Dec  7 2016 aplanas@suse.com
- Set /var/run/neuton for temporal files
* Wed Dec  7 2016 aplanas@suse.com
- Switch to systemd service files
- Fix tmpfiles creation
* Wed Dec  7 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev14:
  * Updated from global requirements
  * Pass network MTU into namespace driver
* Fri Dec  2 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev11:
  * Reduce the amount of smoke tests from 109 to 36
* Wed Nov 30 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev9:
  * Use DB field sizes instead of _MAX_LEN constants
  * Use ExtensionDescriptor from neutron-lib
* Tue Nov 29 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev6:
  * Remove PLURALS
  * Show team and repo badges on README
* Thu Nov 24 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev3:
  * Switch to using plugins directory in lieu of neutron manager
* Sat Nov 19 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-10.0.0.0b2.dev1:
  * Support xenial in devstack install
  10.0.0.0b1
* Tue Nov 15 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev41:
  * Updated from global requirements
* Sat Nov 12 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev40:
  * HAProxy - Add host routes to the lbaas namespace
  * Add openstack tenant id to back-end server call
* Tue Nov  8 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev36:
  * Updated from global requirements
* Sat Nov  5 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev35:
  * Remove last vestiges of oslo-incubator
* Sun Oct 23 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev34:
  * Updated from global requirements
* Thu Oct 20 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev33:
  * Drop MANIFEST.in - it's not needed by pbr
* Tue Oct 18 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev31:
  * Create a consolidated API test
* Mon Oct 17 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev29:
  * Fix various neutron deprecation warnings
* Sat Oct 15 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev27:
  * Updated from global requirements
* Fri Oct 14 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev26:
  * Fix a gate issue with a mock and deprecated call
* Thu Oct 13 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev25:
  * Enable release notes translation
  * Updated from global requirements
* Wed Oct 12 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev22:
  * Fix typo in v2_driver.py
* Tue Oct 11 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev20:
  * Updated from global requirements
  * Switched devstack plugin to stevedore alias for service plugin
  * Fixed lbaasv2 service plugin alias definition
* Wed Oct  5 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev17:
  * Fixed lbaasv2 service plugin alias definition
  * Switch HAProxy health check timeout to seconds
* Fri Sep 30 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev14:
  * Updated from global requirements
* Fri Sep 30 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev13:
  * Use a cached get-pip.py if it is availble
* Wed Sep 28 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev12:
  * Updated from global requirements
* Tue Sep 27 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev11:
  * Updated from global requirements
* Mon Sep 26 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev10:
  * Temporarily support two INTERFACE_DRIVER_OPTS
* Thu Sep 22 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev8:
  * Updated from global requirements
  * Plugin to run neutron-lbaas tests with tempest
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0rc2.dev6:
  * Update reno for stable/newton
  * Updated from global requirements
  9.0.0.0rc1
  * Adds neutron_lbaas.conf and services_lbaas.conf to q-svc command line
  * Import model_base from neutron-lib
* Fri Sep 16 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b4.dev15:
  * Allow creating loadbalancer with network_id
  * haproxy ns driver: set global haproxy maxconn
* Thu Sep 15 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b4.dev12:
  * Tag the alembic migration revisions for Newton
  * Restore haproxy driver config unit tests
* Wed Sep 14 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b4.dev8:
  * Expect project_id in API calls
* Mon Sep 12 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b4.dev7:
  * Updated from global requirements
  * Fix  string interpolation LOG formatted
  * Enable kvm for neutron-lbaas/Octavia gates
* Sun Sep 11 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b4.dev1:
  * Update quota tests to register quota resources
  9.0.0.0b3
* Fri Sep  2 2016 tbechtold@suse.com
- Update to version neutron-lbaas-9.0.0.0b3.dev79:
  * Add special handling for functional tests
  * Use temporary directory for neutron install
  * Updated from global requirements
  * Remove config import unused
  * Cleanup imports in code
  * Reno for lbaas v1 removal
  * Fix L7 Policy creation with Octavia driver
  * Nuke lbaas v1
  * Add the database v1 to v2 migration script in tools
  * Change assertTrue(isinstance()) by optimal assert
  * Add retries upon db error for deleting vip_port
  * Updated from global requirements
  * Constrain remaining tox targets
  * Fix SELECT FOR UPDATE error in postgresql
  * Remove temporary local HasTenant
  * Allow setting "insecure" in neutron_lbaas.conf
  * Add missing "listener_id" attribute to L7 policy
  * Enable DeprecationWarning in test environments
  * Fix typo in the rest_client.py
  * Remove redundant listener existence check in create_l7policy
  * Remove internal function validate_integer already implemented in neutron-lib
  * Adding UT for fix of bug 1554464
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Delete the "self" when call "_set_degraded" function
  * Updating imports for services prov_config options
  * Revert "haproxy ns driver: set global haproxy maxconn"
  * Replace service type "LOADBALANCER" to "LOADBALANCERV2"
  * resource_cleanup method does not delete members
  * Updated from global requirements
  * Add python 3 classifiers
  * devstack: Remove q-lbaasv1 alias
  * gate_hook: Enable q-lbaas explicitly
  * Enable removal of SSL/TLS reference on listener
  * Revert "Implements ProcessMonitor in the haproxy driver"
  * Add integer validation to weight
  * Implements ProcessMonitor in the haproxy driver
  * Use "--pub-key" instead of "--pub_key"
  * Fix deprecation warning for multiple context managers part 2
  * Fix deprecation warning for multiple context managers
  * Use neutron-lib exceptions
  9.0.0.0b2
  * haproxy ns driver: set global haproxy maxconn
  * Use validators from neutron-lib
  * Correct reraising of exception
  * Rename DB columns: tenant -> project
  * Use neutron-lib converters
  * Updated from global requirements
  * Driver exceptions overriden by plugin
  * remove unused LOG
  * Removing deprecated quota_items config from tests
  * Allow tox to be run with python 3
  * Set up hooks for the functional job and add test_migrations test
  * Replace old_lb to old_pool in function delete_pool
  * Fix typo on message
  * Fix broken tests
  * Neutron-LBaaSv2: Shared Pools Scenario Test
- Remove fix_with_lockmode_pgsql.patch (applied upstream)
- Remove openstack-neutron-lbaas-agent (v1). Only openstack-neutron-lbaasv2-agent
  is supported.
* Fri Aug 26 2016 aplanas@suse.com
- Revert generate PID file for systemd (bsc#991985)
* Mon Aug 22 2016 aplanas@suse.com
- Generate PID file for systemd (bsc#991985)
* Wed Aug  3 2016 aplanas@suse.com
- Add fix_with_lockmode_pgsql.patch
  Fix bsc#990818 and bsc#990839 in PostgreSQL
  https://review.openstack.org/#/c/350038/
* Tue Jul 19 2016 vuntz@suse.com
- Add init script for neutron-lbaasv2-agent.
* Thu Jul  7 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev53:
  * Fix tempest scenario tests
  * Updated from global requirements
  * Add Health Monitor Max Retries Down
  * Replace auth_uri option with auth_url in DevStack plugin
  * Skip the check _check_pool_loadbalancer_match in one condition
* Sun Jul  3 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev44:
  * Use tempest.lib tenants_client
  * Remove tempest-lib from test-requirements.txt
  * Fix LBaaS gate
* Wed Jun 29 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev41:
  * Add neutron-lbaas-dashboard devstack guide in README.md
* Tue Jun 28 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev40:
  * Updated from global requirements
* Mon Jun 27 2016 jsuchome@suse.com
- Add systemd service macros (bnc#986415)
  systemd v228 has a separate generator for generating the service
  files from the init scripts, and daemon-reload is needed during
  package installation
* Thu Jun 23 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev39:
  * Updating devstack plugin to filter for specific backport ubuntu versions
  * Updated from global requirements
  * Validate that subnet exists before adding member to pool
* Tue Jun 21 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev35:
  * Fix doc build if git is absent
* Mon Jun 20 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev34:
  * Updated from global requirements
  * Fix subunit trace help
  * Use constants from neutron-lib
  * Add in missing translation for exception
* Thu Jun 16 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev28:
  * Remove unused POT file
* Wed Jun 15 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev26:
  * Refactor gate hooks
* Sun Jun 12 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev24:
  * Fix hard-coding of trusty in devstack plugin.sh
* Sat Jun 11 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-9.0.0.0b2.dev22:
  * Fix test assumptions about IP allocation
  * Preventing listener deletion if it has l7 policy
  * Updated from global requirements
  * Remove check_i18n files
  * Updated from global requirements
  * Add agent haproxy driver setup in README.md
  * Preventing pool deletion if pool has healthmonitor
  * Remove repeat call to 'neutron_agent_lbaas_install_agent_packages'
  9.0.0.0b1
  * Fix no such option defined for service_auth
  * Use --subproject instead of deprecated --service option
  * Fixing creation of shared pool
  * Get Me A LB
  8.1.2
  * Avoid unnecessary debug string evaluation
  * Translation: create the locale directory
* Fri Jun  3 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.1.2.dev37:
  * Add cryptography>=1.0 to requirements.txt
  * Neutron-LBaaS: Update/Delete LB Admin Tests
  8.1.1
* Sat May 21 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.1.1.dev34:
  * Neutron LBaaS Deprecation Update
* Fri May 20 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.1.1.dev32:
  * Updated port validation to not allow port 0
* Thu May 19 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.1.1.dev30:
  * Updated from global requirements
  * Fixing tests to proper compare dicts
  * Neutron-LBaaS: Update/Delete Pools Admin Tests
  * Do not consider listeners without default pool
* Tue May 17 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.1.1.dev23:
  * Updated from global requirements
  * Neutron-LBaaS: Fix network_resources path
  8.1.0
  * correct tox.ini for coverage
  * Updated from global requirements
  * Put sanity back into lbaas jobs
* Wed May 11 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev31:
  * Neutron_LBaaSv2: Update Session Persistence Bug
* Mon May  9 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev30:
  * LBaaS V1 Log error instead of exception
  * Switch to using hacking checks from neutron-lib
  * Finish to port unit tests to Python 3
  * Port test_db_loadbalancer to Python 3
* Mon May  9 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev23:
  * Port even more service tests to Python 3
  * Port more service unit tests to Python 3
* Mon May  9 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev19:
  * Port more unit tests to Python 3
* Mon May  9 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev17:
  * Updated from global requirements
  * Fix test_quotas
  * Set HTTP status code to 409 for LBs in PENDING*
  * Updated from global requirements
  * Neutron-LBaaS: Updated Incorrect Comments
  * Don't use zuul-cloner in venv env, for periodic jobs
* Thu Apr 14 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev7:
  * Port agent_manager to Python 3
  * Port test_agent and test_agent_api to Python 3
  * Port cert_parser to Python 3
  * Tempest tests for Health monitor using  testscenarios
  * Neutron LBaaS:  Base Test Case Class
  * Arista ML2 Mechanism driver
  * Copy the RHEL6 eventlet workaround from Oslo
  * fix bug lp:1025526,update iniparser.py to accept  empty value
  * merged the latest changes from plugin-framework branch - revision 39 conforming to the new cisco plugin directory structure and moving all db related modules into cisco/db folder updated db_test_plugin.py  - added import of cisco constants module  - added LOG.getLogger for logging component name  - updated import module paths for l2network_models/db and ucs_models/db to use the new directory structure  - updated (rearranged) imports section to obey openstack alphabetical placement convention updated db_conn.ini  - updated database name from cisco_naas to quantum_l2network unit test cases ran successfully and pep8 checks done again
  * merge Salvatore's api branch with fixes for tests.  Tweaking branch to remove unwanted bin/quantum.py as part of merge
  * Merging pep8 and functional test related changes lp:~santhom/network-service/quantum_testing_framework branch
* Wed Apr 13 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev4:
  * Move away from locally installed packages
* Sat Apr  9 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.1.dev3:
  * Updated from global requirements
  8.0.0
  * Constraint requirements using mitaka upper-constraints.txt file
  8.0.0.0rc2
  * Update devstack plugin for dependent packages
  * Update .gitreview for stable/mitaka
* Sun Apr  3 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0rc2.dev12:
  * Fix multiple job failures
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0rc2.dev11:
  * correct tox.ini for coverage
  * Add a whitelist of tests passing on Python 3
  * py3: Replace dict.iteritems() with dict.items()
  * py3: Use six.moves for import modules
  * Add support for Guru Meditation Reports for LBaaS agents
  * Adding releasenotes for shared-pools and L7
* Mon Mar 21 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0rc2.dev4:
  * Update reno for stable/mitaka
* Sat Mar 19 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0rc2.dev2:
  * Fix Python 3 issues
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0rc2.dev1:
  * Update devstack plugin for dependent packages
  8.0.0.0rc1
* Wed Mar 16 2016 tbechtold@suse.com
- Set default service_provider in neutron_lbaas.conf
* Wed Mar 16 2016 tbechtold@suse.com
- Remove duplicate Requires
* Wed Mar 16 2016 tbechtold@suse.com
- Add python-cryptography as Requires and BuildRequires
* Tue Mar 15 2016 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b4.dev21:
  * Fix delete of session_persistence with pool update
* Mon Mar 14 2016 tbechtold@suse.com
- Update to version neutron-lbaas-8.0.0.0b4.dev19:
  * Fix lbaas-lb-status when health monitor disabled
  * Delete tempest fork
  * Fix the neutron-lbaas namespace driver gate
  * Tag the alembic migration revisions for Mitaka
  * Make all tox targets constrained
  * Uncouple lbaas object models from neutron core plugin results
  * Add model sync test
  * Fix model vs migration mismatches in nsxv tables
  * Fix model vs migration mismatches for L7 rules and policies
  8.0.0.0b3
  * Revert "Adds Cascade option for load balancer drivers"
  * Adds Cascade Delete for LoadBalancers to Octavia Driver
  * Adds Cascade option for load balancer drivers
  * Track alembic heads
  * Remove synchronous haproxy driver
  * L7 support for Radware LBaaS v2 driver
  * Remove unused pngmath Sphinx extension
  * L7 capability extension implementation for lbaas v2
  * fix mismatch between v1 keyword and v2 driver in gate_hook
  * Fix shared-pools lbaas_listeners migration
  * Set netscaler_ncc_password as secret to prevent it from being logged
  * Updated from global requirements
  * Neutron LBaaS leaking admin_password into logs
  * Updated from global requirements
  * Expand gate hooks to allow for more than just octavia testing
  * Add check for listener's admin_state_up status
  * LBaaS: make use of neutron_lib exceptions
  * Shared pools support
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Migrate some stuff to neutron-lib
  * Updated from global requirements
  * Updated from global requirements
  * Enable debug logging in octavia scenario tests
  * Temporary gate fix for tempest library
  * Updated from global requirements
  * Optimize API gate devstack build time
  * Janky hack to get gate passing
  * Update translation setup
  * Don't always run Octavia amphroa image build
  * Add an explicit BRANCH_NAME to tox_install.sh
  * Set config values and fix casual failing of nc service in scenario tests
  * Make sample web server close connections
  * Updated from global requirements
  * Encode certificate data for processing
  * Adding "region and endpoint_type" parameters to barbican_acl.py
  * Implementing EventStreamer reciever for octavia
  * Refactor BarbicanAuth to allow for configurable auth method
  * Updated from global requirements
  * Allow overriding neutron git location, to allow local clones
  * Remove unused compute clients
  * Remove commented-out import from test client
  8.0.0.0b2
  * Remove invalid fields of healthmonitor when its type is TCP/PING
  * Fix timing bug that causes false negative tests
  * Updated from global requirements
  * VMWare NSXv LBaaSv2 driver
  * Fix lbaas unit tests, new requirement used in neutron base class
  * Clean up removed hacking rule from [flake8] ignore lists
  * Remove vim header from source files
  * Add scenario test for load balancer's session persistence
  * Use the correct _ method from neutron_lbaas._i18n
  * Replaces __builtin__ with six.moves.builtins
  * Updated from global requirements
  * Pass service admin auth from the Octavia driver
  * Update admin auth data for devstack
  * Replace deprecated library function os.popen() with subprocess
  * Do not send project_id to Octavia API on PUTs
  * Remove OpenSSL from cert_parser
  * Fix unit tests failing because of neutron changes
  * Update and enable auth in devstack plugin
  * Use assertTrue/False instead of assertEqual(T/F)
  * Updated from global requirements
  * Keep py3.X compatibility for urllib.urlencode
  * Fix API tests
  * LOG.warn -> LOG.warning
  * Trivial: Remove unused logging import
  * Updated from global requirements
  * Fix db refresh race condition bug
  * Change status to DISABLED if admin_state_up if false
  * Updated from global requirements
  * Avoid duplicating tenant check when creating resources
  * Validate vip_id as uuid
  * Fix a typo from UPPER_CONTRAINTS_FILE to UPPER_CONSTRAINTS_FILE
  * Use keystoneauth to prevent logging sensitive data
  * Deprecated tox -downloadcache option removed
  * Updated from global requirements
  * [LBaaS v2] Validate name, description and tenant_id attributes length
  * Remove Neutron LBaaS static example configuration files
  * Pass config info in neutron-lbaas api v2 tempest tests
  * Fixing Radware LBaaS v2 driver LB deletion
  * VMware LBaaSv1 method uses invalid context
- Adjust Requires
- Do sample config generation with oslo-config-generator
* Tue Dec 15 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev28:
  * Updated from global requirements
* Fri Dec 11 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev27:
  * Updated from global requirements
  * Added constraints tox targets
  * Send project_id/tenant_id to octavia api
* Thu Dec 10 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev22:
  * Automatically generate neutron LBaaS configuration files
  * Updated from global requirements
* Wed Dec  9 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev19:
  * Radware V2: ensure that password is 'secret'
  * Consume LBaaS v2 plugin queue in RPC workers
* Tue Dec  8 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev15:
  * Radware: ensure that password is 'secret'
* Sun Dec  6 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev13:
  * Updated from global requirements
* Sat Dec  5 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev12:
  * Add reno for release notes management
  * Sync db models to migrations
  * Remove version from setup.cfg
  * Validate connection limit for LBaaS
  * Add jobs dashboard to docs
  * lbaasv2: validate tenant-id is non-empty in api
* Fri Dec  4 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.0b2.dev2:
  8.0.0.0b1
  * Put py34 first in the env order of tox
  * Setup for translation
* Thu Dec  3 2015 rhafer@suse.com
- Don't package /etc/neutron-lbaas and /var/log/neutron-lbaas they
  are not used anywhere
- Have lbaas-agent load /etc/neutron/neutron_lbaas.conf as well
* Thu Dec  3 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev89:
  * Add flavor option to loadbalancerv2 creation
  * Updated from global requirements
  * Switch to internal _i18n pattern, as per oslo_i18n guidelines
* Wed Dec  2 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev85:
  * Remove dependency on neutron for topics
  * Remove pylint from pep8
  * Support for Name field in Members and HMs
* Mon Nov 30 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev80:
  * Openstack typo
* Wed Nov 25 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev78:
  * Allow API tests to run in the gate
  * Correct the lbaasv2 pool create code
* Tue Nov 24 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev75:
  * Disable automatic config file discovery for pep8 target
* Sat Nov 21 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev74:
  * Add service_plugins entry_point for LBaaS v2 plugin
  * Switch to using neutron.common.utils:replace_file()
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev70:
  * Updated from global requirements
  * Fix some inconsistency in docstrings
  * Use Octavia stable/liberty branch in DevStack README
  * Fixing TLS configuration issues
  * remove default=None for config options
* Mon Nov 16 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev61:
  * Removed new=True argument from create_connection
* Fri Nov 13 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev59:
  * Revert "Revert "Remove TEMPEST_CONFIG_DIR in the api tox env""
  * Revert "Remove TEMPEST_CONFIG_DIR in the api tox env"
  * Use assertFalse instead of assertEqual
* Thu Nov 12 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev53:
  * Remove TEMPEST_CONFIG_DIR in the api tox env
* Wed Nov 11 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev51:
  * Set ZUUL_BRANCH using BRANCH if not available
  * LBaaS V2 service not needed with Octavia driver
* Fri Nov  6 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev48:
  * Update local.conf to use Cirros 0.3.4
  * Load class should be instantiate with obj
  * Avoiding usage of mutables as default arguments
  * Refine the error message for timeout in test
* Thu Nov  5 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev40:
  * Change haproxy namespace driver to use stevedore alias
  * use assertIs(Not)None instead of assert(Not)Equal
* Sat Oct 31 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev37:
  * [LBaaS v2] Validate http_method and url_path for health monitor
* Fri Oct 30 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev35:
  * Use assert(Not)In instead of assertTrue/False
* Thu Oct 29 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev33:
  * Updated from global requirements
* Mon Oct 26 2015 rhafer@suse.com
- re-enable python-barbicanclient requirement
* Mon Oct 26 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev31:
  7.0.0
  * Update the devstack readme.md for Octavia as ref
  * Filter get_pool_members to return members from the desired pool
  * Allow updating TLS refs
  * Tag the alembic migration revisions for Liberty
  * Use stable/liberty branch for neutron dep
  7.0.0.0rc1
  * Update defaultbranch in .gitreview to stable/liberty
* Sun Oct 25 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev70:
  * Adds a Barbican option to local.conf
* Fri Oct 23 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev68:
  * Add ability for octavia to allocate vip
* Thu Oct 22 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev66:
  * Fix default device_driver entry in lbaas_agent.ini
* Sat Oct 17 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev65:
  * Use noop octavia driver for minimal job too
  * Updated from global requirements
  * Tempest tests for Health monitor using testscenarios
  * Remove the embrane driver
* Fri Oct 16 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev58:
  * Updated from global requirements
* Thu Oct 15 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev57:
  * Include alembic versions directory to the package
  * Enable debug logs for octavia in neutron gate
  * api tests: don't hide exception when creating load balancer
  * Updated from global requirements
  * Fix order of arguments in assertEqual
  * Fix typo in test names for test_health_monitors_non_admin.py in API v2
* Wed Oct 14 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev46:
  * Updated from global requirements
  * Updated from global requirements
  * Do not update apt if devstack is in OFFLINE mode
* Sat Oct 10 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev41:
  * Updated from global requirements
  * [LBaaS v2] Improve API tests performance
  * Fix scenario tests for octavia driver
* Fri Oct  9 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev37:
  * Improve resource cleanup in API v2 tests
* Sun Oct  4 2015 tbechtold@suse.com
- adjust Requires according to requirements.txt
* Sun Oct  4 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev36:
  * Updated from global requirements
* Fri Oct  2 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev35:
  * Allow updating TLS refs
  * Filter get_pool_members to return members from the desired pool
* Wed Sep 30 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev32:
  * tox.ini: check migrations for the subproject only
  * Tag the alembic migration revisions for Liberty
  * Update the devstack readme.md for Octavia as ref
* Tue Sep 29 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev27:
  * Kill HEADS file
* Thu Sep 24 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-8.0.0.dev26:
  * Open Mitaka development
  * Updated from global requirements
  * The minimal test suite is running too many tests
  * Change ignore-errors to ignore_errors
* Wed Sep 23 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b4.dev20:
  * Set Octavia as the reference LBaaSv2 driver
  * Use admin context in octavia driver, improve logs
  * Removed +x flag from alembic script
* Mon Sep 21 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b4.dev15:
  * Split up gate tests for LBaaSv2
  * Various fixes for tempest tests with octavia
  * Updated from global requirements
* Thu Sep 17 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b4.dev12:
  * Add device_id when a loadbalancer is created instead of at listener create
* Wed Sep 16 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b4.dev10:
  * Use "session_persistence" in data models for uniformity with API attribute
* Tue Sep 15 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b4.dev9:
  * Adding barbican to gate hook
* Sat Sep 12 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b4.dev8:
  * Fix health monitor ops in lbaas octavia driver
  * Remove fall-back logic to service provider registration
  * Removing unused dependency: discover
* Fri Sep 11 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b4.dev3:
  * Wait for lb delete on tempest resource_cleanup
  * Add an optional member status of NO_MONITOR
  7.0.0.0b3
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev58:
  * Updated from global requirements
* Sun Aug 30 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev57:
  * Adopt the migration chaining and branch names from neutron
  * Registering Barbican consumers
* Fri Aug 28 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev53:
  * Updated from global requirements
  * Switch to using os-testr's copy of subunit2html
  * Change sni_container plural from ids to refs
  * Fix loading CertManager method
  * Update for NetScaler v2 driver
* Wed Aug 26 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev44:
  * Change tls and sni listener API attributes to ref
  * Fix incorrect module import
* Sat Aug 22 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev42:
  * Updated from global requirements
  * Clean up test_listener_basic scenario
* Fri Aug 21 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev39:
  * Prevent deletion of a subnet with lbaas v1 pool
* Thu Aug 20 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev38:
  * Octavia driver correctly reports statuses
  * Add basic listener scenario tests
* Wed Aug 19 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev34:
  * Refactor v2 scenario tests
* Tue Aug 18 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev32:
  * change if to else in in haproxy namespace drivers
  * Updated from global requirements
  * Remove load_admin_roles from calls to get_admin_context
  * Fix for code redundancy and healthmonitor scenario tests
* Sun Aug 16 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev25:
  * Octavia driver
* Thu Aug 13 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev24:
  * Remove ipv6_pd_enabled from subnet data model
* Thu Aug 13 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev22:
  * Remove requirements.txt from tox.ini
  * Use oslo.log library instead of system logging module
  * Fix typos in namespace_driver.py and some tests
  * Updated from global requirements
  * Fixing Radware LBaaS v2 driver bugs
  * Migrate to multi branch directory structure
* Fri Aug  7 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev12:
  * Updated from global requirements
  * Updating devstack plugin for authtoken
  * Vip delegation
* Wed Aug  5 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev8:
  * Fixes private key loading issue
* Tue Aug  4 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev6:
  * Killed existing downgrade rules in migration scripts
  * Register provider configuration with ServiceTypeManager
  * Install HAProxy 1.5 on Ubuntu Devstack
* Sat Aug  1 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b3.dev2:
  7.0.0.0b2
  * Fix for AttributeError
  * Register alembic_migrations at install time
  * Stop use of oslo_utils.timeutils.strtime()
  * Updated from global requirements
  * script.py.mako: added license text, removed downgrade section
  * Remove quantum untracked files from .gitignore
  * Fix for post_test_hook.sh
  * Scenario test for healthmonitor
  * Fixing Radware LBaaS v2 driver LB deletion
  * Fixes healthmonitor admin_state_up not working issue
  * Forcing cert_parser.dump_private_key to use PKCS8
  * ensure_dir: switch to neutron.common.utils
  * pep8: re-enable neutron-db-manage check_migration
  * Tempest tests for Members using testscenarios
  * Tempest tests for Listener using testscenarios
  * Moved the contents related to DataDrivenTests to a new directory
  * Modified tox.ini to run the ddt tests
  * Updated from global requirements
  * Remove pylint env from tox.ini so tox runs
  * Updated from global requirements
  * New job for LBaaS V2 scenario tests
  * Updated from global requirements
  * Fixing Radware unit tests after mock module update
  * Fix test failures caused by mock update
  * Added admin/non_admin api tests
  * Allow users to run 'tox -epy34'
* Sat Jul 25 2015 seife+obs@b1-systems.com
- fix spec file conditions for non-suse distributions
* Fri Jun 26 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b2.dev3:
  * Ignored several invalid tests
* Thu Jun 25 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0b2.dev1:
  7.0.0.0b1
  * Neutron_LBaaS: Update README.rst for Tests
  * Modified tox.ini and post_test_hook.sh
* Wed Jun 24 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0a1.dev9:
  * Switch to oslo_utils.uuidutils
  * Switching from the ppa to neutron backports
  * Haproxy socket bind failing for IPv6 vip address
* Tue Jun 23 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0a1.dev4:
  * Updated from global requirements
  * Introduced tempest API tests for openstack/neutron-lbaas
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-7.0.0.0a1.dev1:
  * Update version for Liberty
  7.0.0a0
* Sun Jun 14 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev51:
  * Admin API tempest for healthmonitor
  * Adding code to prevent vip port deletion from port api
* Wed Jun 10 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev47:
  * Fix typos
  * Remove unused modules from the test-requirements.txt file
  * Updated from global requirements
* Sat Jun  6 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev42:
  * Updated from global requirements
  * Remove unused 'tempest' tox env
  * Remove unused default value
* Fri Jun  5 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev36:
  * Nuke a useless and incorrect comment from requirements.txt
  * Add a new lbaas agent Scheduler, LeastPoolAgentScheduler
  * Enable random hash seeds
* Thu Jun  4 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev30:
  * Cleaner mechanism for enabling lbaasv2 in devstack-gate
  * Implement KEMPtechnologies lbaas driver v2 shim
* Wed Jun  3 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev27:
  * Get apiv1 tests passing
  * Alias the jenkins job args to match the right tox envs
  * Python 3: use six.iteritems instead of dict.items
  * Do not assume http expected_codes ordering
  * Pull lbaasv1 tempest tests in-tree, use installed neutron for v1/v2 job
* Fri May 29 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev17:
  * Bugfixes and minor improvements to local.sh
* Sat May 23 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev16:
  * Move xrange to six.moves.range for pep8 issue
  * Fix neutron-lbaas tests
* Wed May 20 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev13:
  * Updated from global requirements
* Fri May 15 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev12:
  * Fix scheduler unit tests
* Tue May 12 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev11:
  * Ignore new N324 style requirement
* Sat May  9 2015 cloud-devel@suse.de
- Update to version neutron-lbaas-2015.2.0.dev10:
  2015.1.0
  * Add HaproxyNSDriver to lbaas entry points
  2015.1.0rc2
  * Updated from global requirements
  * update .gitreview for stable/kilo
  * Add Kilo release milestone
  * Pin neutron to stable/kilo
* Fri May  8 2015 dmueller@suse.com
- Initial packaging
